@@ -27,6 +27,7 @@ soundcard.end_export()
 
 """
 import sys
+import os
 from mpd.track import Track, PercussionTrack
 from soundcardexceptions import SoundInitException
 from exporter import MidiExporter
@@ -48,8 +49,10 @@ def play_mediafile(typeid, filename):
     else:
         cmdline = src.cfg.get_string("sound/%s_player" % typeid)
         try:
+            # make the filename absolute, since we also use it in file URIs
             run_external_program(
-                src.cfg.get_string("sound/%s_player" % typeid), "", filename)
+                src.cfg.get_string("sound/%s_player" % typeid), "",
+                os.path.abspath(filename))
         except OsUtilsException, e:
             e.args = e.args + (_("Check the config for %(typeid)s files in the preferences window (Ctrl-F12).") % locals(),)
             raise
@@ -67,8 +70,7 @@ def initialise_external_midiplayer(cmdline, verbose_init=0):
     synth = midifilesynth.MidiFileSynth(cmdline, verbose_init)
 
 
-def initialise_devicefile(devicefile, devicenum=0, card_info=None,
-                          verbose_init=0):
+def initialise_devicefile(devicefile, devicenum=0, verbose_init=0):
     global synth
     if devicefile == '/dev/sequencer2' or devicefile == '/dev/music':
         import oss_sequencer2
@@ -78,8 +80,8 @@ def initialise_devicefile(devicefile, devicenum=0, card_info=None,
         if devicefile != '/dev/sequencer':
             print "warning: the device file is unknown. Assuming it is /dev/sequencer - compatible"
         import oss_sequencer
-        synth = oss_sequencer.OSSSequencerSynth(devicefile, devicenum, 
-                                                card_info, verbose_init)
+        synth = oss_sequencer.OSSSequencerSynth(devicefile, devicenum,
+                                                verbose_init)
 
 def initialise_using_fake_synth(verbose_init=None):
     global synth
