@@ -335,12 +335,30 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         ])
         for d in format_info:
             for bin, opts in {
-                'wav': (('play', '%s'), ('aplay', '%s'), ('esdplay', '%s')),
-                'midi': (('timidity', '-idqq %s'),
+                'wav': (
+                        ('gst-launch', 'playbin uri=file://%s'),
+                        ('gst-launch', 'filesrc location=%s ! wavparse ! alsasink'),
+                        ('play', '%s'),
+                        ('aplay', '%s'),
+                        ('esdplay', '%s')),
+                'midi': (
+                         ('gst-launch', 'playbin uri=file://%s'),
+                         ('gst-launch', 'filesrc location=lesson-files/share/fanfare.midi ! wildmidi ! alsasink'),
+
+                         ('timidity', '-idqq %s'),
                          ('drvmidi', ''),
                          ('playmidi', '')),
-                'mp3': (('mpg123', ''), ('alsaplayer', '')),
-                'ogg': (('ogg123', ''), ('alsaplayer', ''))}[d['id']]:
+                'mp3': (
+                        ('gst-launch', 'playbin uri=file://%s'),
+                        ('gst-launch', 'filesrc location=%s ! mad ! alsasink'),
+                        ('mpg123', ''),
+                        ('alsaplayer', '')),
+                'ogg': (
+                        ('gst-launch', 'playbin uri=file://%s'),
+                        ('gst-launch', 'filesrc location=%s ! oggdemux ! vorbisdec ! audioconvert ! alsasink'),
+                        ('ogg123', ''), 
+                        ('alsaplayer', ''))
+                        }[d['id']]:
                 v = osutils.find_progs((bin,))
                 if v:
                     d['players'].append((v[0], " ".join((v[0], opts))))
@@ -366,9 +384,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             category_vbox.pack_start(box)
     def test_XXX_player(self, w, typeid, testfile):
         try:
-            osutils.run_external_program(
-                self.g_player_boxes[typeid].child.get_text(),
-                'lesson-files/share', testfile)
+            soundcard.play_mediafile(typeid, os.path.join('lesson-files/share', testfile))
         except Exception, e:
             self.m_app.m_ui.display_exception_message(e)
     def create_linux_sound_page(self):
@@ -399,17 +415,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         hbox.pack_start(self.g_device_file, False)
         hbox.pack_start(self.g_synth_num, False)
 
-        # checkbox to enable awe support
-        hbox = gtk.HBox()
-        category_vbox.pack_start(hbox, False)
-        hbox.pack_start(gtk.Label("    "))
-        self.g_awe_checkbutton = gtk.CheckButton(_("_My sound card is Sound Blaster AWE32, AWE64 or pnp32"))
-        self.g_awe_checkbutton.set_active(self.get_string('sound/card_info') == 'awe')
-        if not buildinfo.HAVE_LINUX_AWE_VOICE_H:
-            self.g_awe_checkbutton.set_sensitive(False)
-        else:
-            self.g_awe_checkbutton.set_sensitive(self.get_string("sound/type") == "sequencer-device")
-        hbox.pack_start(self.g_awe_checkbutton, False)
         ###
         hbox = gu.bHBox(category_vbox, False)
         self.g_midiplayer_radio = gu.RadioButton(self.g_fakesynth_radio,
@@ -427,7 +432,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         category_vbox.pack_start(hbox)
         gu.bButton(category_vbox, _("_Apply changes and play test sound"), self.on_apply_and_play_test_sound)
 
-        self.g_device_radio.connect('toggled', lambda w: self.g_awe_checkbutton.set_sensitive(w.get_active()))
     def create_win32_sound_page(self):
         page_vbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(page_vbox, gtk.Label(_("Midi setup")))
@@ -515,7 +519,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                 raise
     def on_apply(self, *v):
         """Returns -1 if sound init fails."""
-        card_info = ""
         if soundcard.synth:
             soundcard.synth.close()
         if self.g_midiplayer_radio.get_active():
@@ -523,19 +526,13 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                   self.g_player_boxes['midi'].child.get_text())
             soundcard.synth.error_report_cb = self.m_app.m_ui.display_error_message
         elif self.g_device_radio.get_active():
-            if sys.platform != 'win32' and buildinfo.HAVE_LINUX_AWE_VOICE_H and \
-                self.g_awe_checkbutton.get_active():
-                card_info = "awe"
-            else:
-                card_info = ""
             try:
                 if sys.platform == 'win32':
                     soundcard.initialise_winsynth(self.g_synth.get_active() - 1)
                 else:
                     soundcard.initialise_devicefile(
                         self.g_device_file.child.get_text(),
-                        self.g_synth_num.get_value_as_int(),
-                        card_info)
+                        self.g_synth_num.get_value_as_int())
             except (soundcard.SoundInitException, OSError, ImportError), e:
                 self.m_app.display_sound_init_error_message(e)
                 return -1
@@ -554,7 +551,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             self.set_string("sound/type", "fake-synth")
         if sys.platform != 'win32':
             self.set_string("sound/device_file", self.g_device_file.child.get_text())
-            self.set_string("sound/card_info", card_info)
         if soundcard.synth.m_type_major not in ('Midifile', 'Fake'):
             self.set_int("sound/synth_number", soundcard.synth.m_devnum)
             # we set the spin just in case m_devnum was changed by the
