@@ -22,6 +22,7 @@ import re
 import soundcard
 import cfg
 import os
+import sys
 
 PAD = 8
 PAD_SMALL = 4
@@ -500,6 +501,16 @@ def create_rhythm_image(rhythm):
     im.show()
     return im
 
+def decode_filename(filename):
+    """
+    Decode the filename we get from FileChooser.get_filename()
+    We need to do this for every filename.
+    """
+    if sys.platform == 'win32':
+        return filename.decode("utf-8")
+    else:
+        return filename.decode(sys.getfilesystemencoding())
+
 
 class EditorDialogBase(gtk.Window):
     # Classes inheriting from this must define self.savedir
@@ -578,12 +589,12 @@ class EditorDialogBase(gtk.Window):
             try:
                 if (not self.m_filename) and (not self.m_changed):
                     win = self.new_file()
-                    win.load_file(dialog.get_filename())
+                    win.load_file(decode_filename(dialog.get_filename()))
                     win.set_title(win.m_filename)
                     self.destroy()
                 else:
                     win = self.new_file()
-                    win.load_file(dialog.get_filename())
+                    win.load_file(decode_filename(dialog.get_filename()))
                     win.set_title(win.m_filename)
             except Exception, e:
                 # Since we catch all sorts of exceptions here, we don't have
@@ -621,11 +632,11 @@ class EditorDialogBase(gtk.Window):
         while 1:
             ret = dialog.run()
             if ret == gtk.RESPONSE_OK:
-                if os.path.exists(dialog.get_filename()):
+                if os.path.exists(decode_filename(dialog.get_filename())):
                     if not dialog_yesno(_("File exists. Overwrite?")):
                         continue
                 try:
-                    self.m_filename = dialog.get_filename()
+                    self.m_filename = decode_filename(dialog.get_filename())
                     self.save()
                     self.set_title(self.m_filename)
                 except IOError, e:
@@ -668,13 +679,13 @@ class EditorDialogBase(gtk.Window):
                 dialog.destroy()
                 return
             elif res == gtk.RESPONSE_OK:
-                if os.listdir(dialog.get_filename()):
+                if os.listdir(decode_filename(dialog.get_filename())):
                     msg_dlg = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
                         gtk.MESSAGE_INFO, gtk.BUTTONS_OK, msg)
                     msg_dlg.run()
                     msg_dlg.destroy()
                 else:
                     break
-        ret = dialog.get_filename()
+        ret = decode_filename(dialog.get_filename())
         dialog.destroy()
         return ret
