@@ -79,7 +79,7 @@ _keys_to_interval = {
               -10: '-M6', #c -> eses
                -9: '-a2', #c -> beses
                -8: '-a5', #c -> fes
-               -7: '-au', #c -> ces
+               -7: '-a1', #c -> ces
                -6: '-a4', #c -> ges
                -5: 'm2', # c -> des
                -4: '-M3',# c -> as
@@ -93,7 +93,7 @@ _keys_to_interval = {
                 4: 'M3', # c -> e
                 5: '-m2', # c -> b
                 6: 'a4', # c -> fis
-                7: 'au', #c -> cis
+                7: 'a1', #c -> cis
                 8: 'a5', # c -> gis
                 9: 'a2', # c -> dis
                 10: 'M6', # c -> ais
