@@ -395,7 +395,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
                 if splash_win:
                     splash_win.hide()
                 gu.dialog_ok(_("Failed to load learning tree"), self, 
-                    _("Ignoring the file \"%(filename(s\" because of this error: %(error)s") % {
+                    _("Ignoring the file \"%(filename)s\" because of this error: %(error)s") % {
                     'filename': fullpath,
                     'error': str(e).decode(sys.getfilesystemencoding(), 'replace'),
                     }, gtk.MESSAGE_ERROR)
