@@ -200,8 +200,6 @@ class AbstractStatistics:
         return num_correct * 100.0 / total
     def key_to_pretty_name(self, k):
         return k
-    def get_label_style(self):
-        return 'normal'
     def reset_session(self):
         self.m_session_stat = {}
 
@@ -225,8 +223,6 @@ class LessonStatistics(AbstractStatistics):
         """
         self.m_savepath = os.path.join(filesystem.app_data(),
                 'statistics', self.m_t.m_P.header.lesson_id)
-    def get_label_style(self):
-        return self.m_t.m_P.header.labelformat
     def lessonfile_changed(self, new_file):
         if not new_file:
             return
@@ -292,8 +288,8 @@ class LessonStatistics(AbstractStatistics):
         return hash(open(self.m_cur_file).read())
     def key_to_pretty_name(self, key):
         for question in self.m_t.m_P.m_questions:
-                if question.name.cval == key:
-                    return question.name
+            if question.name.cval == key:
+                return question.name
         return key
 
 class IntervalStatistics(LessonStatistics):
